# Changelog

## [2023.11.12]

### Added

- Doc updates
- Updates to pyproject.toml for first upload

## [2023.11.05]

### Added

- Initial version of reflection client
- Simple set of tests against sample server
- Initial documentation
